IPStack

Enum IPStack 

pub enum IPStack {
    IPv6,
    IPv4,
    Dual,
}
Available on crate feature io only.
IP stack.

Variants



IPv6

IPv6 only.



IPv4

IPv4 only.



Dual

IPv6 and IPv4.

Implementations

Source

impl IPStack

pub fn reachable_addresses( &self, include_loopbacks: bool, ) -> Result<Vec<ListenableAddress>>

Get all reachable addresses.

Reachable addresses are always specified. As such they provide an explicit alternative to using unspecified addresses (e.g. “::” for IPv6 and “0.0.0.0” for IP4) for binding functions.

This function works by enumerating all the interfaces and their addresses and checking each address for reachability.

The result could be an empty vector if no reachable addresses are found. Also, there if no guarantee for order. In particular, IPv6 and IPv4 are not grouped separately for Dual.

Source

impl IPStack

pub fn allows_ipv6(&self) -> bool

Whether the stack allows IPv6.

pub fn allows_ipv4(&self) -> bool

Whether the stack allows IPv4.

pub fn allows(&self, address: &IpAddr) -> bool

Whether the stack allows the address.